<?php

class PerchCampaignMonitor extends PerchAPI_Factory
{
    protected $table     = 'cm_stats';
	protected $pk        = 'statsID';
	protected $singular_classname = 'PerchCampaignMonitor_Stat';
	
	protected $default_sort_column = 'statID';
	
    
    /**
     * update the feed.
     */
	public function update_data($api_key, $list_id) 
	{
		$success = false;

		$stats_array = array();
	    $subs_array = array();
	    
	   	$wrap = new CS_REST_Lists($list_id, $api_key);
	    	
	    //get list data
	    $my_list = $wrap->get();
	    if($my_list->was_successful()) {
	    	//delete info from stats table
	    	$this->db->execute('TRUNCATE TABLE '.$this->table);
	    	//store title in data array
	    	$stats_array['title'] = $my_list->response->Title;
	    }
	    
	    	
	    //get list stats
	   	$stats = $wrap->get_stats();
	    
	    if($stats->was_successful()) {
		    $stats_array['total'] = $stats->response->TotalActiveSubscribers;
		    $stats_array['yesterday'] = $stats->response->NewActiveSubscribersYesterday;
		    $stats_array['today'] = $stats->response->NewActiveSubscribersToday;

		    $success = true;
	    }else{
	    	$success = false;
	    }
	    
	    //insert stats array
	    $this->db->insert($this->table, $stats_array);
	    
	    //create history array, first check to see if we already have a row for yesterday
	   $sql = 'SELECT * FROM '.PERCH_DB_PREFIX .'cm_history WHERE historyDate = '.$this->db->pdb(date('Y-m-d', strtotime('-1 days'))) . ' LIMIT 1';
	   if(!$row = $this->db->get_row($sql)) {
	   		//insert a row for yesterday
	   		$history_data = array(
	   			'historyDate'=>date('Y-m-d', strtotime('-1 days')),
	   			'historyTotal'=>$stats_array['yesterday']
	   		);
	   		$this->db->insert(PERCH_DB_PREFIX .'cm_history',$history_data);
	   }
	   
	   $subs = $wrap->get_active_subscribers(date('Y-m-d', strtotime('-90 days')), 1, 10, 'date', 'desc');
	   PerchUtil::debug($subs->response->Results);
	    	
	   if($subs->was_successful()) {
	   	$success = true;

	   	//empty table
	   	$this->db->execute('TRUNCATE TABLE '.PERCH_DB_PREFIX .'cm_subscribers');
	   	//store latest data
		foreach($subs->response->Results as $sub) {
			$subs_array = array(
		    	'subscriberDate'=>$sub->Date,
		    	'subscriberEmail'=>$sub->EmailAddress
		    );
			PerchUtil::debug($subs_array);
			$this->db->insert(PERCH_DB_PREFIX .'cm_subscribers',$subs_array);
		    		
		}
	   }else{
	   	$success = false;
	   }
	    
			
		return $success;
	}
    
	
    
    /**
     * get the stored data for display on the dashboard
     */
    public function get_data()
    {
		//get the stats
        $sql = 'SELECT * FROM '.$this->table .' LIMIT 1';

        $row = $this->db->get_row($sql);
        if($row) {
	        //get the subscribers
	        $sql = 'SELECT * FROM '.PERCH_DB_PREFIX .'cm_subscribers ORDER BY subscriberDate DESC LIMIT 5';
	        $rows = $this->db->get_rows($sql);
	        $row['subscribers'] = $rows;
	              
	        return $this->return_instance($row);
        }
        return false;
    }
    
   
	
}
?>